<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="hu_HU" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="67"/>
        <source>Behavior</source>
        <translation>Működés</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically save documents</source>
        <translation>Automatikusan mentse a dokumentumokat</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Restore window geometry</source>
        <translation>Az ablak méretének visszaállítása</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Open external links in ReText window</source>
        <translation>Külső hivatkozások megnyitása a ReText-ben</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Editor</source>
        <translation>Szerkesztő</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Highlight current line</source>
        <translation>Aktuális sor kiemelése</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Show line numbers</source>
        <translation>Sorszámok megjelenítése</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tab key inserts spaces</source>
        <translation>A tabulátor szóközöket használ</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tabulation width</source>
        <translation>Tabulátorszélesség</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Interface</source>
        <translation>Program felület</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Icon theme name</source>
        <translation>Ikontéma neve</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Stylesheet file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="103"/>
        <source>Help</source>
        <translation type="unfinished">Súgó</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Use live preview by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Draw vertical line at column</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="34"/>
        <source>(none)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="41"/>
        <source>Select file to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Nyelv megadása (például: hu_HU)</translation>
    </message>
    <message>
        <location filename="dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Beállítás alapértelmezettként</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Images (*.png *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="tab.py" line="177"/>
        <source>New document</source>
        <translation>Új dokumentum</translation>
    </message>
    <message>
        <location filename="tab.py" line="182"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Nem tudtuk elemezni a fájl tartalmát, kérjük ellenőrizze, hogy a &lt;a href=&quot;%s&quot;&gt;szükséges modul&lt;/a&gt; telepítve van-e!</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="81"/>
        <source>File toolbar</source>
        <translation>Fájl eszköztár</translation>
    </message>
    <message>
        <location filename="window.py" line="83"/>
        <source>Edit toolbar</source>
        <translation>Szerkesztés eszköztár</translation>
    </message>
    <message>
        <location filename="window.py" line="85"/>
        <source>Search toolbar</source>
        <translation>Keresés eszköztár</translation>
    </message>
    <message>
        <location filename="window.py" line="89"/>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <location filename="window.py" line="92"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>Set encoding</source>
        <translation>Kódolás</translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Save as</source>
        <translation>Mentés másként...</translation>
    </message>
    <message>
        <location filename="window.py" line="111"/>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Print preview</source>
        <translation>Nyomtatási előnézet</translation>
    </message>
    <message>
        <location filename="window.py" line="116"/>
        <source>View HTML code</source>
        <translation>HTML kód megtekintése</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Find text</source>
        <translation>Szöveg keresése</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Preview</source>
        <translation>Előnézet</translation>
    </message>
    <message>
        <location filename="window.py" line="135"/>
        <source>Live preview</source>
        <translation>Élő előnézet</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Fullscreen mode</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <location filename="window.py" line="553"/>
        <source>Preferences</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="window.py" line="159"/>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <location filename="window.py" line="162"/>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <location filename="window.py" line="164"/>
        <source>Redo</source>
        <translation>Újra végrehajtás</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <location filename="window.py" line="170"/>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <location filename="window.py" line="180"/>
        <source>Enable</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Set locale</source>
        <translation>Nyelv beállítása</translation>
    </message>
    <message>
        <location filename="window.py" line="182"/>
        <source>Use WebKit renderer</source>
        <translation>Használja a WebKit megjelenítőt</translation>
    </message>
    <message>
        <location filename="window.py" line="188"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="window.py" line="190"/>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <location filename="window.py" line="195"/>
        <source>Get help online</source>
        <translation>Online súgó</translation>
    </message>
    <message>
        <location filename="window.py" line="196"/>
        <source>About ReText</source>
        <translation>Névjegy: ReText</translation>
    </message>
    <message>
        <location filename="window.py" line="199"/>
        <source>About Qt</source>
        <translation>Névjegy: Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Bold</source>
        <translation>Félkövér</translation>
    </message>
    <message>
        <location filename="window.py" line="216"/>
        <source>Italic</source>
        <translation>Dőlt</translation>
    </message>
    <message>
        <location filename="window.py" line="218"/>
        <source>Underline</source>
        <translation>Aláhúzás</translation>
    </message>
    <message>
        <location filename="window.py" line="230"/>
        <source>Symbols</source>
        <translation>Szimbólumok</translation>
    </message>
    <message>
        <location filename="window.py" line="235"/>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <location filename="window.py" line="236"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="window.py" line="237"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="window.py" line="240"/>
        <source>Open recent</source>
        <translation>Legutóbbi megnyitása</translation>
    </message>
    <message>
        <location filename="window.py" line="252"/>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <location filename="window.py" line="273"/>
        <source>Spell check</source>
        <translation>Helyesírás-ellenőrzés</translation>
    </message>
    <message>
        <location filename="window.py" line="281"/>
        <source>Default markup</source>
        <translation>Alapértelmezett formátum</translation>
    </message>
    <message>
        <location filename="window.py" line="284"/>
        <source>Formatting</source>
        <translation>Formázás</translation>
    </message>
    <message>
        <location filename="window.py" line="321"/>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <location filename="window.py" line="323"/>
        <source>Case sensitively</source>
        <translation>Betűérzékeny</translation>
    </message>
    <message>
        <location filename="window.py" line="458"/>
        <source>New document</source>
        <translation>Új dokumentum</translation>
    </message>
    <message>
        <location filename="window.py" line="622"/>
        <source>Please, save the file somewhere.</source>
        <translation>Kérjük mentse el a fájlt másik helyre.</translation>
    </message>
    <message>
        <location filename="window.py" line="187"/>
        <source>Show directory</source>
        <translation>Mappa mutatása</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Select one or several files to open</source>
        <translation>Jelöljön ki egy vagy több fájlt megnyitásra</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Supported files</source>
        <translation>Támogatott fájltípusok</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>All files (*)</source>
        <translation>Minden fájl (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="776"/>
        <source>Select file encoding from the list:</source>
        <translation>Válassza ki a kódolást a listából:</translation>
    </message>
    <message>
        <location filename="window.py" line="797"/>
        <source>Plain text (*.txt)</source>
        <translation>Egyszerű szöveg (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="800"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s fájlok</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>Save file</source>
        <translation>Fájl mentése</translation>
    </message>
    <message>
        <location filename="window.py" line="821"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Nem menthető, mert a fájl írásvédett!</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>Export document to ODT</source>
        <translation>Dokumentum exportálása ODT formátumba</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument szöveg fájlok (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML fájlok (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>Export document to PDF</source>
        <translation>Dokumentum exportálása PDF-be</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF fájlok (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="908"/>
        <source>Print document</source>
        <translation>Dokumentum nyomtatása</translation>
    </message>
    <message>
        <location filename="window.py" line="932"/>
        <source>Export document</source>
        <translation>Dokumentum exportálása</translation>
    </message>
    <message>
        <location filename="window.py" line="953"/>
        <source>Failed to execute the command:</source>
        <translation>Nem tudtuk végrehajtani ezt a parancsot:</translation>
    </message>
    <message>
        <location filename="window.py" line="1064"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Ezt a dokumentumot ön módosította.
El kívánja menteni a változtatásokat?</translation>
    </message>
    <message>
        <location filename="window.py" line="1089"/>
        <source>HTML code</source>
        <translation>HTML kód</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Egyszerű, de nagy tudású Markdown és reStructuredText szerkesztő</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Szerző: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Website</source>
        <translation>Weboldal</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Markdown syntax</source>
        <translation>Markdown szintaxis</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText szintaxis</translation>
    </message>
    <message>
        <location filename="window.py" line="1044"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="107"/>
        <source>Next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="140"/>
        <source>Table editing mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>FakeVim mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1028"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1035"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="117"/>
        <source>Change editor font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="119"/>
        <source>Change preview font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="192"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="987"/>
        <source>Alt text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>Link text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
